@@ -1,6 +1,8 @@
-#!/bin/bash
+#!/bin/sh
+# SPDX-License-Identifier: LGPL-2.1+
 
-set -ex
+set -eu
+[ -n "${DEBUG:-}" ] && set -x
 
 [ $(id -u) -eq 0 ]
 
@@ -11,7 +13,7 @@ topdir=$(dirname ${dirname})
 testdir=`mktemp -t -d libs.XXX`
 installdir=`mktemp -t -d libs.XXX`
 pidfile=$(mktemp)
-libdir=${installdir}/usr/lib
+libdir=${installdir}/usr/lib/lxcfs
 bindir=${installdir}/usr/bin
 lxcfspid=-1
 FAILED=1
@@ -35,14 +37,21 @@ cleanup() {
   fi
 }
 
-trap cleanup EXIT SIGHUP SIGINT SIGTERM
+trap cleanup EXIT HUP INT TERM
 
-( cd ${topdir}; DESTDIR=${installdir} make install )
-export LD_LIBRARY_PATH=${libdir}
+echo "==> Installing lxcfs to temporary path"
+( cd ${topdir}; DESTDIR=${installdir} make -s install >/dev/null 2>&1)
+if [ -n "${LD_LIBRARY_PATH:-}" ]; then
+    export LD_LIBRARY_PATH="${libdir}:${LD_LIBRARY_PATH}"
+else
+    export LD_LIBRARY_PATH=${libdir}
+fi
 
+echo "==> Spawning lxcfs"
 ${bindir}/lxcfs -p ${pidfile} ${testdir} &
 
 lxcfspid=$!
+
 count=1
 while [ ! -d ${testdir}/proc ]; do
   [ $count -lt 5 ]
@@ -51,19 +60,24 @@ while [ ! -d ${testdir}/proc ]; do
 done
 
 rm -f /tmp/lxcfs-iwashere
+
+echo "==> Testing that lxcfs is functional"
 cat ${testdir}/proc/uptime
+
 [ ! -f /tmp/lxcfs-iwashere ]
 (
-  cd ${topdir};
-  make liblxcfstest.la
-  gcc -shared -fPIC -DPIC .libs/liblxcfstest_la-bindings.o .libs/liblxcfstest_la-cpuset.o -lpthread -pthread -o .libs/liblxcfstest.so
+  cd ${topdir}/src;
+  make -s liblxcfstest.la
+  gcc -shared -fPIC -DPIC -Wl,-soname,liblxcfs.so .libs/liblxcfstest_la-*.o cgroups/.libs/liblxcfstest_la-*.o -lpthread -pthread -o .libs/liblxcfstest.so
   cp .libs/liblxcfstest.* "${libdir}"
-)
+) > /dev/null
 rm -f ${libdir}/liblxcfs.so* ${libdir}/liblxcfs.la
 cp ${libdir}/liblxcfstest.so ${libdir}/liblxcfs.so
 
 kill -USR1 ${lxcfspid}
-
+sleep 1
 cat ${testdir}/proc/uptime
+sleep 1
 [ -f /tmp/lxcfs-iwashere ]
+
 FAILED=0
